@@ -40,4 +40,4 @@ def ColorLevelReset(self):
     self.cSlide_B.setValue(0)
     self.LevelApply(self.core.curThumb,  False)
     self.LevelApply(self.core.curIm,  True)
-    self.FullScreenToggle(True, 1)
+    FullScreenToggle(self, True, 1)
