@@ -7,6 +7,7 @@ import glob
 import math
 import operator
 import os
+import time
 import sys
 import webbrowser
 from subprocess import call
@@ -19,7 +20,8 @@ from PyQt4 import QtGui as QtGui
 from PyQt4.QtCore import pyqtSignature
 from PyQt4.QtGui import QMainWindow
 
-import imports.EXIF
+from imports.EXIF import *
+from core.config import *
 from core.browser import *
 from core.core import *
 from core.buttons import *
@@ -42,7 +44,10 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     """
     core=ParamValues()
 
-        
+    #######################################
+    #   Initial 
+    #######################################
+
     def __init__(self, parent = None):
         """
         Constructor
@@ -50,97 +55,36 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         try:
             QMainWindow.__init__(self, parent)
             self.setupUi(self)
+
+        except:
+            print "Error: init"
+            return
             
-            FileImageOpen(self,  self.core.curImageLoc)
-            self.ShowApply(False)
-            self.postSetup()
-            
-            
-            FileImageRefresh(self)
-            self.ShowApply(False)
+    def postShow(self):
+        try:
+            ReadConfig(self)
+            PhotTabs_Hide(self)
+            WaitOverlay(self,"Starting...")
+            ##FullScreenToggle(self,True, 2)
+            self.tabStrip.setCurrentIndex(2)
+            ##self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            self.photo.setMouseTracking= True
+            populatePhotoList(self)
+            WaitOverlayHide(self)
+            self.listPhotositemLoad(self.listPhotos.item(0))
+            ##reply = QtGui.QMessageBox.question(self, 'Message',"Are you sure to quit?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+       
+            if (self.listPhotos.item(0) == None):
+                FileImageOpen(self,  self.core.curImageLoc)
+            ShowApply(self, False)
             self.core.plotIm=Image.open("/opt/anselA/ui/resources/graph.png") 
         except:
-            return
+            print "Error: postShow"
+            
 
-    def postSetup(self):
-        self.tabStrip.setCurrentIndex(0)
-        self.photo.setMouseTracking= True
-        populatePhotoList(self)
-        self.listPhotositemLoad(self.listPhotos.item(0))
-
-    @pyqtSignature("")
-    def on_btnExitGo_released(self):
-        sys.exit()
-        
-        
-    @pyqtSignature("Bool")
-    def ShowApply(self, Show):
-        if self.core.ApplyVisible <> Show:
-            self.core.ApplyVisible = Show
-            self.btnApplyUndo.setText(":"+str(self.core.undoCount))
-            if Show:
-                self.btnApply.setVisible(True)
-                self.btnApplyUndo.setVisible(True)
-            else:
-                self.btnApply.setVisible(False)
-                self.btnApplyUndo.setVisible(False)
-        
-    @pyqtSignature("Bool, Image")
-    def showUpdateLabel(self, show,  thumb):
-        self.ShowApply(True)
-        self.lockUpdating = show
-        if (thumb == True):
-            if (show == True):
-                self.labWaitThumb.setGeometry(-30, -30, 380, 450)
-            else:
-                self.labWaitThumb.setGeometry(QtCore.QRect(0, 0, 0, 0))
-        else:
-            if (show == True):
-                self.FullScreenToggle(True)
-                self.labWait.setGeometry(QtCore.QRect(0, 0, 797, 433))
-            else:
-                self.FullScreenToggle(False)
-                self.labWait.setGeometry(QtCore.QRect(0, 0, 0, 433))
-        self.labWait.repaint()
-        self.repaint()
-
-    
-    @pyqtSignature("")
-    def on_btn_Grey_released(self):
-        self.core.valBW = "L"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    @pyqtSignature("")
-    def on_btn_Red_released(self):
-        self.core.valBW = "R"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    @pyqtSignature("")
-    def on_btn_Green_released(self):
-        self.core.valBW = "G"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    @pyqtSignature("")
-    def on_btn_Blue_released(self):
-        self.core.valBW = "B"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
- 
-    @pyqtSignature("")
-    def on_btn_Yellow_released(self):
-        self.core.valBW = "Y"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    @pyqtSignature("")
-    def on_btn_Cyan_released(self):
-        self.core.valBW = "C"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-    
-    @pyqtSignature("")
-    def on_btn_Magenta_released(self):
-        self.core.valBW = "M"
-        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
-
-    @pyqtSignature("int")
+    #######################################
+    #   Color Sliders
+    #######################################
     def on_cSlide_B_valueChanged(self, value):
         if (self.core.valB <> value):
             self.core.valB = cSlide_SetValue(self, value,  self.core.valB,  self.lcdB, self.cSlide_B)
@@ -180,44 +124,97 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.core.valG = cSlide_ShiftValue(self, -1,  self.core.valG,  self.lcdG, self.cSlide_G)
     
 
-    @pyqtSignature("int")
-    def on_cSlide_Hi_valueChanged(self, value):
-        self.core.valHi = value
-        self.lcdHi.setText(str(self.core.valHi))
-    
-    @pyqtSignature("int")
+  
+    #######################################
+    #   Level Applys
+    #######################################
+  
     def on_cSlide_Mi_valueChanged(self, value):
-        self.core.valMi = value
-        self.lcdMi.setText(str(self.core.valMi))
-    
-    @pyqtSignature("int")
-    def on_cSlide_Sw_valueChanged(self, value):
-        self.core.valSw = value
-        self.lcdSw.setText(str(self.core.valSw))
+        if (self.core.valMi <> value):
+            self.core.valMi = cSlide_SetValue(self, value,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi)
         
-    @pyqtSignature("int")
-    def on_cSlide_Sh_valueChanged(self, value):
-        self.core.valSh = value
-        self.lcdSh.setText(str(self.core.valSh))
-        Simple_Adjustments(self,self.core.current.thumb,  "Sh",  False)
+    def on_btnSlide_Mid_dn_pressed(self):
+        self.core.valMi= cSlide_ShiftValue(self,  -1,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi)
+            
+    def on_btnSlide_Mid_up_pressed(self):
+        self.core.valMi = cSlide_ShiftValue(self,  1,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi)
+  
+  
+    def on_cSlide_Hi_valueChanged(self, value):
+        if (self.core.valHi <> value):
+            self.core.valHi = cSlide_SetValue(self, value,  self.core.valHi,  self.lcdHi, self.cSlide_Hi)
+
+    def on_btnSlide_H_dn_pressed(self):
+        self.core.valHi = cSlide_ShiftValue(self,  -1,  self.core.valHi,  self.lcdHi, self.cSlide_Hi)
+        
+    def on_btnSlide_H_up_pressed(self):
+        self.core.valHi = cSlide_ShiftValue(self,   1,  self.core.valHi,  self.lcdHi, self.cSlide_Hi)
     
-    @pyqtSignature("int")
-    def on_cSlide_Sa_valueChanged(self, value):
-        self.core.valSa = value
-        self.lcdSa.setText(str(self.core.valSa))
-        Simple_Adjustments(self,self.core.current.thumb,  "Sa",  False)
+    
+    def on_cSlide_Sw_valueChanged(self, value):
+        if (self.core.valSw <> value):
+            self.core.valSw = cSlide_SetValue(self, value,  self.core.valSw,  self.lcdSw, self.cSlide_Sw)
+        
+    def on_btnSlide_Sha_dn_pressed(self):
+        self.core.valSw = cSlide_ShiftValue(self,  -1,  self.core.valSw,  self.lcdSw, self.cSlide_Sw)
+        
+    def on_btnSlide_Sha_up_pressed(self):
+        self.core.valSw = cSlide_ShiftValue(self,   1,  self.core.valSw,  self.lcdSw, self.cSlide_Sw)
+
+
+   
+    #######################################
+    #   Level Applys
+    #######################################
     
     @pyqtSignature("int")
     def on_cSlide_Co_valueChanged(self, value):
-        self.core.valCo = value
-        self.lcdCo.setText(str(self.core.valCo))
-        Simple_Adjustments(self,self.core.current.thumb,  "Co",  False)
+        if (self.core.valCo != value):
+            self.core.valCo = cSlide_SetValue(self, value,  self.core.valCo,  self.lcdCo, self.cSlide_Co)
+        
+    def on_btnSlide_Co_dn_pressed(self):
+        self.core.valCo = cSlide_ShiftValue(self,  -1,  self.core.valCo,  self.lcdCo, self.cSlide_Co)
+        
+    def on_btnSlide_Co_up_pressed(self):
+        self.core.valCo = cSlide_ShiftValue(self,   1,  self.core.valCo,  self.lcdCo, self.cSlide_Co)
+    
+    
+    @pyqtSignature("int")
+    def on_cSlide_Sh_valueChanged(self, value):
+        if (self.core.valSh <> value):
+            self.core.valSh = cSlide_SetValue(self, value,  self.core.valSh,  self.lcdSh, self.cSlide_Sh)
+            
+    def on_btnSlide_Sh_dn_pressed(self):
+        self.core.valSh = cSlide_ShiftValue(self,  -1,  self.core.valSh,  self.lcdSh, self.cSlide_Sh)
+        
+    def on_btnSlide_sh_up_pressed(self):
+        self.core.valSh = cSlide_ShiftValue(self,   1,  self.core.valSh,  self.lcdSh, self.cSlide_Sh)
+
+        
+    @pyqtSignature("int")
+    def on_cSlide_Sa_valueChanged(self, value):
+        if (self.core.valSa <> value):
+            self.core.valSa = cSlide_SetValue(self, value,  self.core.valSa,  self.lcdSa, self.cSlide_Sa)
+    
+    def on_btnSlide_Sa_up_pressed(self):
+        self.core.valSa = cSlide_ShiftValue(self,   1,  self.core.valSa,  self.lcdSa, self.cSlide_Sa)
+        
+    def on_btnSlide_Sa_dn_pressed(self):
+        self.core.valSa = cSlide_ShiftValue(self,  -1,  self.core.valSa,  self.lcdSa, self.cSlide_Sa)
+        
     
     @pyqtSignature("int")
     def on_cSlide_Br_valueChanged(self, value):
-        self.core.valBr = value
-        self.lcdBr.setText(str(self.core.valBr))
-        Simple_Adjustments(self,self.core.current.thumb,  "Br",  False)
+        if (self.core.valBr <> value):
+            self.core.valBr = cSlide_SetValue(self, value,  self.core.valBr,  self.lcdBr, self.cSlide_Br)
+    
+    def on_btnSlide_Br_dn_pressed(self):
+        self.core.valBr = cSlide_ShiftValue(self,  -1,  self.core.valBr,  self.lcdBr, self.cSlide_Br)
+        
+    def on_btnSlide_Br_up_pressed(self):
+        self.core.valBr = cSlide_ShiftValue(self,  1,  self.core.valBr,  self.lcdBr, self.cSlide_Br)
+        
+        
         
     @pyqtSignature("int")
     def on_dial_valueChanged(self, value):
@@ -226,51 +223,49 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             self.lcdRot_1.setText(str(self.core.valRot))
             RotateThumb(self,  value)
            
-    @pyqtSignature("")
+
+    #######################################
+    #   UI Reactions
+    #######################################
+
     def on_btnExitCancel_released(self):
-        self.tabStrip.setCurrentIndex(self.core.valCurTab)
-        self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        self.tabStrip.setCurrentIndex(self.core.GetCurrentTab(self))
+        self.FramePopup.setGeometry(QtCore.QRect(0, 0, 0, 0))
         
-    @pyqtSignature("")
+    def on_btnPopOk_released(self):
+        sys.exit()
+    
+    def on_btnPopCancel_released(self):
+        self.tabStrip.setCurrentIndex(self.core.GetCurrentTab(self))
+        self.FramePopup.setGeometry(QtCore.QRect(0, 0, 0, 0))
+
     def on_minMax_released(self):
         return MinMax()
-
+        
     def on_photo_released(self):
         QMessageBox.information(self, "Loading Data", "Please wait while the data is retrieved...")
 
-    @pyqtSignature("int")
-    def on_tabStrip_currentChanged(self, index):
-        """
-        Slot documentation goes here.
-        """
-        if (index==9):
-            self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
-        elif  (index==6):
-            ReturnHistPlots(self)
-        elif (index==7):
-            self.PopulateEXIFData(self.core.curImageLoc)
-        else:
-            self.core.valCurTab = index
-    
-    @pyqtSignature("")
+   
     def on_btnOpen_released(self):
         return FileOpenReleased(self)
        
-    @pyqtSignature("Image, String")
     def PopulateEXIFData(self,  filename):
         return ImageExifLoad(self)
         
-    @pyqtSignature("int")
     def on_tabPhoto_currentChanged(self, index):
-        if (index == 2):
-            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        if (self.tabPhoto.count != 1):
+            if (index == 2):
+                ##self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
+                if self.core.thumbsCount == 0:
+                    return populatePhotoList(self)
+                self.photoListZoom.setVisible(False)
+            elif (index ==1):
+               self.loadUndoImages()
+        else:
+            #self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
             if self.core.thumbsCount == 0:
                 return populatePhotoList(self)
-        elif (index ==1):
-           self.loadUndoImages()
-        else:
-            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 90, 800, 371))
-            
+                
     def loadUndoImages(self):
         self.btnUndoCancel.setVisible(False)
         self.btnUndoGo.setVisible(False)
@@ -285,92 +280,89 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
                 
             self.listUndoList.item(i).setIcon(icon)
             i+=1
-            
+                
 
-#++++++++++++++++++++++  END of Class    
+    #######################################
+    #  Full Screen
+    #######################################
 
-    
-    
-    @pyqtSignature("")
     def on_btnFullScreen_released(self):
         """
-        utton handler for fullscreen  open, calls FullScreenToggle
+        Button handler for fullscreen  open, calls FullScreenToggle
         """
-        self.FullScreenToggle(True)
+        FullScreenToggle(self,True)
     
-    @pyqtSignature("")
-    def on_btnFullScreenClose_released(self):
-        """
-        Button handler for fullscreen  close, calls FullScreenToggle
-        """
-        self.FullScreenToggle(False)
 
-    @pyqtSignature("")
-    def FullScreenToggle(self,  Show,  ForceTab=0):
-        """
-        Slot documentation goes here.
-        """
-        if (Show):
-            self.tabPhoto.setCurrentIndex(ForceTab)
-            self.framePhoto.setGeometry(QtCore.QRect(0, 0, 800, 480))    
-            self.photo.repaint()
-            #self.photo_Orig.repaint()
-        else:
-            self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
-            
-        self.tabPhoto.updateGeometry()
-        self.tabStrip.repaint()
-        self.repaint()
+    def on_btnFullScreenClose_released(self):
+        FullScreenToggle(self,False)
+
     
-    @pyqtSignature("")
+    def on_tabStrip_currentChanged(self, index):
+        if (index==9):
+            self.FramePopup.setGeometry(QtCore.QRect(0, 0, 800, 480))
+        elif  (index==6):
+            ReturnHistPlots(self)
+        elif (index==7):
+            self.PopulateEXIFData(self.core.curImageLoc)
+        else:
+            self.core.SetCurrentTab(self.tabStrip.currentIndex() )
+        
+    #######################################
+    #   B & W Settings
+    #######################################
+    def on_btn_Grey_released(self):
+        self.core.valBW = "L"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    
+    def on_btn_Red_released(self):
+        self.core.valBW = "R"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+
+    def on_btn_Green_released(self):
+        self.core.valBW = "G"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    
+    def on_btn_Blue_released(self):
+        self.core.valBW = "B"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+ 
+    def on_btn_Yellow_released(self):
+        self.core.valBW = "Y"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    
+    def on_btn_Cyan_released(self):
+        self.core.valBW = "C"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+    
+    def on_btn_Magenta_released(self):
+        self.core.valBW = "M"
+        Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
+        
     def on_btn_BC_released(self):
-        """
-        Black and white conversion to Blue-Cyan
-        """
         self.core.valBW = "BC"
         Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
     
-    @pyqtSignature("")
     def on_btn_GC_released(self):
-        """
-        Black and white conversion to Green-Cyan
-        """
         self.core.valBW = "GC"
         Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
     
-    @pyqtSignature("")
     def on_btn_GY_released(self):
-        """
-        Black and white conversion to Green-Yellow
-        """
         self.core.valBW = "GY"
         Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
     
-    @pyqtSignature("")
     def on_btn_BM_released(self):
-        """
-        Black and white conversion to Blue-Magenta
-        """
         self.core.valBW = "BM"
         Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
         
-    @pyqtSignature("")
     def on_btn_RM_released(self):
-        """
-        Black and white conversion to Red-Magenta
-        """
         self.core.valBW = "RM"
         Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
     
-    @pyqtSignature("")
     def on_btn_RY_released(self):
-        """
-        Black and white conversion to Red-yellow
-        """
         self.core.valBW = "RY"
         Convert_BW(self, self.core.current.thumb,  self.core.valBW,  False)
 
-    @pyqtSignature("")
+
     def on_btnBug_released(self):
         """
         Submit bug report to bugs.maemo.org
@@ -378,113 +370,82 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         url='https://bugs.maemo.org/enter_bug.cgi?product=AnselA'
         os.system('browser --url=%s' %url)
 
-    @pyqtSignature("")
+
+    #######################################
+    #   Photo Browser
+    #######################################
+
     def on_btnPListCancel_released(self):
-        """
-        Slot documentation goes here.
-        """
         self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 0, 0))
         self.core.populatePhotoList = False
-    
 
-        
-    @pyqtSignature("")
     def on_btnPlistZoom_released(self):
-        """
-        This button displays the Zoomed Image, click on it will edit the photo.
-        """
+        AnimateWidget(self, self.photoListZoom, 155-int(self.photoListZoom.width()/2) , 195-int(self.photoListZoom.height()/2), 0, 0, 10)
         LoadCurImageFromPhotoBrowser(self)
-        #self.listPhotos.setCurrentRow(8)
 
-    def ToggleThumbWait(self,  Show):
-        if Show:
-            self.labWaitThumb.setGeometry(-30, -30, 380, 450)
-
-        else:
-            self.labWaitThumb.setGeometry(0, 0, 0, 0)
-    
-    @pyqtSignature("")
     def on_butReturn_released(self):
-        """
-        Slot documentation goes here.
-        """
-        self.FullScreenToggle(False)
+        FullScreenToggle(self,False)
     
-    
-    @pyqtSignature("QListWidgetItem*")
     def on_listPhotos_itemDoubleClicked(self, item):
-        """
-        Slot documentation goes here.
-        """
-        self.LoadCurImageFromPhotoBrowser()
+        #((155-int(self.photoListZoom.width()/2)) , 0, 0, 0, 10))
+        AnimateWidget(self, self.photoListZoom, 155-int(self.photoListZoom.width()/2) , 195-int(self.photoListZoom.height()/2), 0, 0, 10)
+        LoadCurImageFromPhotoBrowser(self)
     
-    @pyqtSignature("")
     def on_btnReloadPList_released(self):
-        """
-        Slot documentation goes here.
-        """
-        self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 791, 441))
+        self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
     
-    @pyqtSignature("")
     def on_btnReloadCancel_released(self):
-        """
-        Slot documentation goes here.
-        """
         self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
     
-    @pyqtSignature("")
     def on_btnReloadGo_released(self):
-        """
-        Slot documentation goes here.
-        """
-        self.btnEditZoomed.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        #self.btnEdit.setGeometry(QtCore.QRect(0, 0, 0, 0))
         self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
         populatePhotoList(self,  True)
-    
-    @pyqtSignature("")
+  
+    def on_btnRefresh_pressed(self):
+        populatePhotoList(self)
+
     def on_btnPhotoBrowser_released(self):
-        """
-        Slot documentation goes here.
-        """
-        self.FullScreenToggle(True,  2)
+        FullScreenToggle(self,True,  2)
         
         if self.core.thumbsCount == 0:
             self.populatePhotoList(self,  True)
     
-  
-
-    @pyqtSignature("QListWidgetItem*")
     def on_listPhotos_itemClicked(self, item):
-        """
-        Slot documentation goes here.
-        """
-        #return listPhotosClicked()
+       #return listPhotosClicked()
         if str(item.text()) == "Load More...":
             self.core.thumbsCount +=100
-            self.populatePhotoList()
-            self.btnEditZoomed.setGeometry(QtCore.QRect(220, 280, 281, 0))
+            populatePhotoList(self,  False)
+
+            self.btnEditZoomed.setGeometry(QtCore.QRect(40, 120, 250, 150))
         else:
             self.listPhotositemLoad(item)
             
     def listPhotositemLoad(self, item):
-        self.photoListZoom.setGeometry(item.getIconZoomSize())
-        self.btnPlistZoom.setGeometry(self.photoListZoom.geometry())
-        self.core.plistIm= self.core.imageDir+str(item.text())+".jpg"
-        im = Image.open(self.core.plistIm)
-        wTh,  hTh = convertImSize(self.core, im.size[0], im.size[1],  400)
-
-        plistTim=im.resize((hTh,  wTh))
-        self.photoListZoom.setPixmap(pil2qpixmap(plistTim))
-        self.photoListZoom.repaint()
+        if (item <> None):
+            
+            self.core.plistIm= item.getImageLocation()
+            im = Image.open(self.core.plistIm)
+            item.rotation= GetExifRotation(self, item.imageLocation)
+            im = rotateImage(self, im, item.rotation)
+            
+            wTh,  hTh = convertImSize(self.core, im.size[0], im.size[1],  250,  150, item.rotation,  1) #This should be the same size as the thumbnailbnails
+            item.setIconZoomSize(self.ScaleLabel(195,  400, hTh, wTh))
+            
+            self.photoListZoom.setGeometry(item.getIconZoomSize())
+            self.btnPlistZoom.setGeometry(self.photoListZoom.geometry())
+            
+            plistTim=im.resize((hTh,  wTh))
+            self.photoListZoom.setPixmap(pil2qpixmap(plistTim))
+            
+            self.photoListZoom.setVisible(True)
+            self.photoListZoom.repaint()
         
-    @pyqtSignature("QListWidgetItem*")
+
     def on_listUndoList_itemPressed(self, item):
-        """
-        Slot documentation goes here.
-        """
         self.btnUndoCancel.setVisible(True)
         self.btnUndoGo.setVisible(True)
-        if (item.text == "Original"):
+        if (str(item.text()) == "Original"):
             self.core.undoSelected = 0
         else:
             self.core.undoSelected = str(item.text().replace("Step: ",""))
@@ -498,41 +459,23 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         and h,w of image passed.
         """
         return QtCore.QRect(xW-int(w/2), yH-int(h/2), w, h)
-
     
-    @pyqtSignature("")
-    def on_btnSaveAs_released(self):
-        fileLoc=StripFilename(self, self.core.curImageLoc)
-        self.btnSaveAsFilename.setText(fileLoc[1]+"_2")
-        self.btnSaveAsLocation.setText(fileLoc[0])
-        self.frameSaveAs.setGeometry(0, 40, 800, 480)
-
-    @pyqtSignature("")
-    def on_btnSaveAsCancel_pressed(self):
-        self.frameSaveAs.setGeometry(0, 40, 0, 480)
-    
-    @pyqtSignature("")
-    def on_btnSaveAsGo_pressed(self):
-        self.core.current.image.save(self.btnSaveAsFilenameString().replace("JPEG", "jpg"), str(self.btnSaveAsCombo.currentText()))
-        self.frameSaveAs.setGeometry(0, 40, 0, 480)
-    
-    @pyqtSignature("")
+    #######################################
+    #   Apply and Undo
+    #######################################
     def on_btnApply_released(self):
         """
         Apply based on tab selection
         """
         ApplyGo(self)
-    
-    @pyqtSignature("")
+
     def on_btnUndoGo_released(self):
-        self.core.UndoImage_Set()
-        self.loadUndoImages()
-        
-        self.ToggleThumbWait(True)
-        self.FullScreenToggle(False)
-        FileImageRefresh(self)
-        
+        UndoGo(self)
+       
         
+    #######################################
+    #   Rotation
+    #######################################    
     def on_btn_rot_Vert_released(self):
         self.core.flipRight = not self.core.flipRight 
         FlipThumb(self)
@@ -553,20 +496,103 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.core.valRot = 180
         RotateThumb(self,  self.core.valRot)
     
+    
+    
+    
+    #######################################
+    #   Save As
+    #######################################
+    def on_btnSaveAs_released(self):
+        self.DisplaySaveAs()
+
+
+    def on_btnSaveAsCancel_pressed(self):
+        self.frameSaveAs.setGeometry(0, 40, 0, 480)
+    
+        
+    def on_btnSaveAsGo_pressed(self):
+        WaitOverlay(self,"Saving File...")
+        self.frameSaveAs.setGeometry(0, 40, 0, 480)
+        try:
+            self.core.current.image.save(self.btnSaveAsFilenameString().replace("JPEG", "jpg"), str(self.btnSaveAs_Combo.currentText()))
+        except IOError:
+            WaitOverlayOk(self,"Error: Could Not Write File")
+        except:
+            WaitOverlayOk(self,"Error: Failed to Save")
+        finally:
+            WaitOverlayOk(self,"Save Completed")
+        
+        
+        
     def btnSaveAsFilenameString(self):
-        return str(self.btnSaveAsLocation.text())+"/"+str(self.btnSaveAsFilename.text())+"."+str(self.btnSaveAsCombo.currentText())
+        return str(self.btnSaveAs_Location.text())+"/"+str(self.btnSaveAs_Filename.text())+"."+str(self.btnSaveAs_Combo.currentText())
         
     def btnSaveAsfindFileExists(self):
         if os.path.isfile(self.btnSaveAsFilenameString()):
-            self.btnSaveAsGo.setVisible(False)
+            self.btnSaveAsGo.setEnabled(False)
         else:
-            self.btnSaveAsGo.setVisible(True)
+            self.btnSaveAsGo.setEnabled(True)
             
-    def on_btnSaveAsCombo_currentIndexChanged(self, index):
+    def btnSaveAsGenFilename(self, Dir, File):
+        i=1
+        while os.path.isfile(Dir+File+"_"+str(i)):
+            i +=1
+        return i
+        
+    def on_btnSaveAs_Combo_editTextChanged(self, p0):
         self.btnSaveAsfindFileExists()
+        
+    def on_btnSaveAs_Location_textChanged(self, p0):
+        self.btnSaveAsfindFileExists()
+        
+    def on_btnSaveAs_Filename_textChanged(self, p0):
+        self.btnSaveAsfindFileExists()
+    
+    def on_btnSaveAsCancelOut_pressed(self):
+        self.frameSaveAs.setGeometry(0, 40, 0, 480)
+        
+    def on_btnSaveAsMore_pressed(self):
+        if (str(self.btnSaveAsMore.text()) == "More"):
+            self.btnSaveAsMore.setText("Less")
+            self.frameSaveAuto.setVisible(False)
+            self.frameSaveAvd.setVisible(True)
+        else:
+            self.btnSaveAsMore.setText("More")
+            self.frameSaveAvd.setVisible(False)
+            self.frameSaveAuto.setVisible(True)
 
-    def on_btnSaveAsLocation_textChanged(self, p0):
-        self.btnSaveAsfindFileExists()
 
-    def on_btnSaveAsFilename_textChanged(self, p0):
-        self.btnSaveAsfindFileExists()
+    def on_btnPopWaitOk_pressed(self):
+        WaitOverlayHide(self,)
+        
+    def on_btnApplyUndo_pressed(self):
+        FullScreenToggle(self,True,  1)
+    
+    def on_btnEdit_pressed(self):
+        AnimateWidget(self, self.photoListZoom, 40, 0, 0, 0, 10)
+        LoadCurImageFromPhotoBrowser(self)
+    
+    def on_btnRefreshExp_pressed(self):
+        if (str(self.btnRefreshExp.text()) =="+"):
+            self.btnRefreshExp.setText("-")
+            self.btnReloadPList.setGeometry(QtCore.QRect(400, 370, 111, 51))
+            self.btnOpen.setGeometry(QtCore.QRect(510, 370, 111, 51))
+            self.btnRefresh.setGeometry(QtCore.QRect(250, 370, 151, 51))
+        else:
+            self.btnRefreshExp.setText("+")
+            self.btnReloadPList.setGeometry(QtCore.QRect(400, 370, 111, 0))
+            self.btnOpen.setGeometry(QtCore.QRect(510, 370, 111, 0))
+            self.btnRefresh.setGeometry(QtCore.QRect(250, 370, 151, 0))
+    
+    def on_btnPopMinimize_pressed(self):
+        ui.showMinimized()
+    
+    def on_SearchPhoto_Mcc_toggled(self, checked):
+        if (checked):
+           SetConfig_SearchSettings(self, 1)
+        else:
+            SetConfig_SearchSettings(self, 0)
+    
+    @pyqtSignature("")
+    def on_btnSaveSettings_pressed(self):
+        WriteConfig(self)
